# plain.esbuild

**Build JavaScript files with esbuild.**

- [gitignore](#gitignore)
- [Installation](#installation)

## gitignore

```
**/assets/**/*.esbuilt.*
```

## Installation

Install the `plain.esbuild` package from [PyPI](https://pypi.org/project/plain.esbuild/):

```bash
uv add plain.esbuild
```
